import { addTooltip } from "../ui/tooltip";
import { cmRange, hoverContentsToString } from "../utils/conversions";
const states = new WeakMap();
/**
 * Show hover information.
 * @param editor
 * @param pos Position of the event
 * @param hover
 * @param renderMarkdown
 */
export const showHoverInfo = (editor, pos, hover, renderMarkdown = (x) => x) => {
    removeHoverInfo(editor);
    if (Array.isArray(hover.contents) && hover.contents.length === 0)
        return;
    const info = hoverContentsToString(hover.contents, renderMarkdown);
    if (!info)
        return;
    const state = states.get(editor) || {};
    let start = pos;
    if (hover.range) {
        let end = pos;
        [start, end] = cmRange(hover.range);
        state.marker = editor.markText(start, end, {
            css: "text-decoration: underline",
        });
    }
    const el = document.createElement("div");
    el.innerHTML = info;
    const coords = editor.charCoords(start, "page");
    state.tooltip = addTooltip(el, coords.left, coords.top);
    states.set(editor, state);
};
/**
 * Remove hover information from the editor.
 * @param editor
 */
export const removeHoverInfo = (editor) => {
    const state = states.get(editor);
    if (!state)
        return;
    if (state.marker)
        state.marker.clear();
    if (state.tooltip)
        state.tooltip.remove();
    states.delete(editor);
};
export const hoverInfoEnabled = (editor) => { var _a; return !((_a = states.get(editor)) === null || _a === void 0 ? void 0 : _a.disabled); };
export const disableHoverInfo = (editor) => {
    removeHoverInfo(editor);
    states.set(editor, { disabled: true });
};
export const enableHoverInfo = (editor) => {
    removeHoverInfo(editor);
};
//# sourceMappingURL=hover.js.map