/// <reference types="codemirror/addon/hint/show-hint" />
import type { Editor, EditorChange } from "codemirror";
import type { Stream, Disposer } from "./utils/event-stream";
export interface EditorEventMap {
    changes: [cm: Editor, changes: EditorChange[]];
    cursorActivity: [cm: Editor];
    contextmenu: [cm: Editor, event: MouseEvent];
    "cmw:contextMenuOpened": [cm: Editor];
    "cmw:contextMenuClosed": [cm: Editor];
    blur: [cm: Editor];
    viewportChange: [cm: Editor, from: Number, to: Number];
    refresh: [cm: Editor];
}
export interface EditorEventTarget<K extends keyof EditorEventMap> {
    on(type: string, handler: (...args: EditorEventMap[K]) => void): void;
    off(type: string, handler: (...args: EditorEventMap[K]) => void): void;
}
export declare const fromEditorEvent: <K extends "blur" | "contextmenu" | "changes" | "cursorActivity" | "cmw:contextMenuOpened" | "cmw:contextMenuClosed" | "viewportChange" | "refresh">(target: EditorEventTarget<K>, type: K) => Stream<EditorEventMap[K]>;
export declare const onEditorEvent: <K extends "blur" | "contextmenu" | "changes" | "cursorActivity" | "cmw:contextMenuOpened" | "cmw:contextMenuClosed" | "viewportChange" | "refresh">(target: EditorEventTarget<K>, type: K, handler: (args: EditorEventMap[K]) => void) => Disposer;
/**
 * Typed wrapper around `CodeMirror.signal`.
 * @param editor - Editor instance
 * @param name - Event name
 * @param args - Event parameters
 */
export declare const signal: <K extends "blur" | "contextmenu" | "changes" | "cursorActivity" | "cmw:contextMenuOpened" | "cmw:contextMenuClosed" | "viewportChange" | "refresh">(editor: Editor, name: K, ...args: EditorEventMap[K]) => void;
